==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/kitchen/dialogs_nl.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("O, dit is een mooie kombuis.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Ja hoor, we hebben de kombuis gevonden.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Verdraaide kombuis.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver`s kitchen.")
dialogStr("En nu zitten we in de kombuis van kapitein Silver.")


dialogId("kuch-v-varil", "font_big", "I don`t think he was a cook himself.")
dialogStr("Ik denk niet dat hij zelf veel kookte.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Maar dat is niet ons probleem.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Dit is eenvoudig, ik kan hier zo uit zwemmen.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Kijk eens hoe ik er aan toe ben.")


dialogId("kuch-v-stolky0", "font_big", "I can`t understand how these serving tables got there.")
dialogStr("Ik kan me niet voorstellen hoe die tafels zo terecht zijn gekomen.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Deze tafels staan in de weg.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Ik krijg claustrofobie.")


dialogId("kuch-v-odsud0", "font_big", "I can`t get out of here!")
dialogStr("Ik zit vast!")


dialogId("kuch-m-premyslim0", "font_small", "I`m just thinking how to help you.")
dialogStr("Eens denken hoe ik je hieruit kan bevrijden.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Doe iets!")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Ik denk na...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Ik kom eraan.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Bah, er zit nog iets in deze pot!")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn`t even washed up.")
dialogStr("Ze hebben deze pot niet afgewassen.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Ze hebben de vaat laten staan.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Als die stoel daar niet stond was dit allemaal een stuk eenvoudiger.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Vooral voor mij.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Wat doet een stoel in deze kombuis?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Stoelen horen niet thuis in de kombuis.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Iedereen wil wel eens even zitten.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("Ik heb deze tafels als eens eerder gezien.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Dat is massaproductie, joh.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Maar ik vind ze wel mooi. Misschien moeten we er een paar bestellen.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("Ik vrees dat alleen ik hier weg kan komen.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Het lijkt erop dat dit schip een aantal lastige hindernissen bevat.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Wat doet dit zwaard hier?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Misschien heeft de kok daarmee het vlees gesneden.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don`t cut meat with a sword in the kitchen, usually.")
dialogStr("Natuurlijk. Maar normaalgesproken snij je vlees in de keuken niet met een zwaard.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Gelukkig is de kok er niet. Hij zou ons misschien wel willen klaarmaken!")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Op dat stuk perkament staat vast een recept.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Op dat stuk perkament staat vast eenofander culinair raatsel.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Waarschijnlijk staat er hoe je vis moet klaarmaken.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/kitchen/dialogs_nl.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Goh, dit is een mooie kombuis.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Ja hoor, we hebben de kombuis gevonden.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Verdraaide kombuis.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver’s kitchen.")
dialogStr("En nu zitten we in de kombuis van kapitein Silver.")


dialogId("kuch-v-varil", "font_big", "I don’t think he was a cook himself.")
dialogStr("Ik denk niet dat hij zelf veel kookte.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Maar dat is niet ons probleem.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("Dit is eenvoudig, ik kan hier zo uit zwemmen.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Kijk eens hoe ik er aan toe ben.")


dialogId("kuch-v-stolky0", "font_big", "I can’t understand how these serving tables got there.")
dialogStr("Ik begrijp niet hoe die tafels zo terecht zijn gekomen.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Deze tafels staan in de weg.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Ik vind dit kleine kamertje niet zo fijn.")


dialogId("kuch-v-odsud0", "font_big", "I can’t get out of here!")
dialogStr("Ik zit hier vast!")


dialogId("kuch-m-premyslim0", "font_small", "I’m just thinking how to help you.")
dialogStr("Eens denken hoe ik je hieruit kan bevrijden.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("Doe iets!")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Ik denk na...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Ik kom eraan.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Bah, er zit nog iets in deze pot!")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn’t even washed up.")
dialogStr("Ze hebben deze pot niet afgewassen.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Ze hebben de vaat laten staan.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Als die stoel daar niet stond was dit allemaal een stuk eenvoudiger.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Vooral voor mij.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("Wat doet een stoel in deze kombuis?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("Stoelen horen niet in de kombuis.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Iedereen wil wel eens even zitten.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("Ik heb deze tafels als eens eerder gezien.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Dat is massaproductie, joh.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Maar ik vind ze wel mooi. Misschien moeten we er een paar bestellen.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("Ik vrees dat alleen ik hieruit weg kan komen.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Het lijkt erop dat dit schip een aantal lastige hindernissen bevat.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("Wat doet dit zwaard hier?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Misschien heeft de kok daarmee het vlees gesneden.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don’t cut meat with a sword in the kitchen, usually.")
dialogStr("Natuurlijk. Maar normaalgesproken snij je vlees in de keuken niet met een zwaard.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Gelukkig is de kok er niet. Hij zou ons misschien wel willen klaarmaken!")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Op dat stuk perkament staat vast een recept.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Op dat stuk perkament staat vast eenofander culinair raadsel.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Waarschijnlijk staat er hoe je vis moet klaarmaken.")
